Gothenburg Black Tide Gothenburg, Sweden April 13th 2002 12 players Johan Hansson Deck Name: Breed Bleed Crypt (12 cards, min=12, max=26, avg=4.83) ------------------------------------------ 2x Remilliard, Devout Crusader 4 AUS pre Toreador antitribu:2 2x Lolita 3 for pre Toreador antitribu:2 1x Greta Kircher 7 AUS CEL PRE obf Toreador antitribu:2 1x Jessica 7 AUS CEL OBT PRE bishop Toreador antitribu:2 1x Ian Wallingford 6 CEL PRE aus bishop Toreador antitribu:2 1x Jost Werner 6 AUS PRE ani Toreador antitribu:2 1x Sheila Mezarin 6 AUS PRE cel for Toreador antitribu:2 1x Mercy, Knight Inquisitor 5 AUS cel dom pre Toreador antitribu:2 1x Victor Revell, Loyalist 5 CEL aus dem pre Toreador antitribu:2 1x Carter 2 cel Toreador antitribu:2 Library (84 cards) Master (25) 1x Dreams of the Sphinx 4x Hungry Coyote, The 6x Palla Grande 10x Presence 4x Tribute to the Master Action (41) 7x Art Scam 16x Embrace, The 2x Entrancement 3x Intimidation 3x Legal Manipulations 10x Social Charm Action Modifier (6) 6x Change of Target Combat (12) 12x Catatonic Fear